==> dioxus-0.1.8.crate: dioxus-0.1.8/docs/reference/src/SUMMARY.md <==
# Summary

- [Introduction](README.md)

- [Web](web/index.md)
- [Desktop](desktop/index.md)
- [Mobile](mobile/index.md)
- [SSR](ssr/index.md)
- [TUI](tui/index.md)
  
- [Advanced Guides](guide/index.md)
  - [RSX in Depth](guide/rsx_in_depth.md)
  - [Components](guide/components.md)
  - [Props](guide/props.md)
  - [Memoization](guide/memoization.md)
  - [Performance](guide/performance.md)
  - [Testing](guide/testing.md)
  - [Building Elements with NodeFactory](guide/rsx.md)
  - [Custom Elements](guide/custom_elements.md)
  - [Custom Renderer](guide/custom_renderer.md)
  - [Server-side components](guide/server_side_components.md)
  - [Bundling and Distributing](guide/bundline.md)

- [Reference Guide](reference/reference.md)
  - [Anti-patterns](reference/anti.md)
  - [Children](reference/children.md)
  - [Conditional Rendering](reference/conditional.md)
  - [Controlled Inputs](reference/controlled.md)
  - [Custom Elements](reference/custom.md)
  - [Empty Components](reference/empty.md)
  - [Error Handling](reference/error.md)
  - [Fragments](reference/fragments.md)
  - [Global CSS](reference/global.md)
  - [Inline Styles](reference/inline.md)
  - [Iterators](reference/iterators.md)
  - [Listeners](reference/listeners.md)
  - [Memoization](reference/memoization.md)
  - [Node Refs](reference/node.md)
  - [Spread Pattern](reference/spread.md)
  - [State Management](reference/state.md)
  - [Suspense](reference/suspense.md)
  - [task](reference/task.md)
  - [Testing](reference/testing.md)

==> dioxus-0.2.4.crate: dioxus-0.2.4/docs/reference/src/SUMMARY.md <==
# Summary

- [Introduction](README.md)

- [Platforms](platforms/index.md)
  - [Web](platforms/web.md)
  - [Server Side Rendering](platforms/ssr.md)
  - [Desktop](platforms/desktop.md)
  - [Mobile](platforms/mobile.md)
  - [TUI](platforms/tui.md)
  
- [Advanced Guides](guide/index.md)
  - [RSX in Depth](guide/rsx_in_depth.md)
  - [Components](guide/components.md)
  - [Props](guide/props.md)
  - [Memoization](guide/memoization.md)
  - [Performance](guide/performance.md)
  - [Testing](guide/testing.md)
  - [Building Elements with NodeFactory](guide/rsx.md)
  - [Custom Elements](guide/custom_elements.md)
  - [Custom Renderer](guide/custom_renderer.md)
  - [Server-side components](guide/server_side_components.md)
  - [Bundling and Distributing](guide/bundline.md)

- [Reference Guide](reference/reference.md)
  - [Anti-patterns](reference/anti.md)
  - [Children](reference/children.md)
  - [Conditional Rendering](reference/conditional.md)
  - [Controlled Inputs](reference/controlled.md)
  - [Custom Elements](reference/custom.md)
  - [Empty Components](reference/empty.md)
  - [Error Handling](reference/error.md)
  - [Fragments](reference/fragments.md)
  - [Global CSS](reference/global.md)
  - [Inline Styles](reference/inline.md)
  - [Iterators](reference/iterators.md)
  - [Listeners](reference/listeners.md)
  - [Memoization](reference/memoization.md)
  - [Node Refs](reference/node.md)
  - [Spread Pattern](reference/spread.md)
  - [State Management](reference/state.md)
  - [Suspense](reference/suspense.md)
  - [task](reference/task.md)
  - [Testing](reference/testing.md)
